@@ -44,7 +44,12 @@ class GridFile(object):
         """Open a "file" in GridFS.
 
         Application developers should generally not need to instantiate this
-        class directly.
+        class directly - instead see the `gridfs.GridFS.open` method.
+
+        Only a single opened GridFile instance may exist for a file in gridfs
+        at any time. Care must be taken to close GridFile instances when done
+        using them. GridFiles support the context manager protocol (the "with"
+        statement).
 
         Raises TypeError if file_spec is not an instance of dict, database is
         not an instance of `pymongo.database.Database`, or collection is not an
@@ -102,7 +107,7 @@ class GridFile(object):
             file_spec["length"] = 0
             file_spec["uploadDate"] = datetime.datetime.utcnow()
             file_spec.setdefault("chunkSize", 256000)
-            self.__id = self.__collection.files.insert(file_spec)["_id"]
+            self.__id = self.__collection.files.insert(file_spec)
 
         # we use repr(self.__id) here because we need it to be string and
         # filename gets tricky with renaming. this is a hack.
@@ -302,3 +307,16 @@ class GridFile(object):
         """
         for line in sequence:
             self.write(line)
+
+    def __enter__(self):
+        """Support for the context manager protocol.
+        """
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        """Support for the context manager protocol.
+
+        Close the file and allow exceptions to propogate.
+        """
+        self.close()
+        return False # propogate exceptions
