@@ -131,6 +131,11 @@ class Collection(object):
     def save(self, to_save, manipulate=True, safe=False):
         """Save a document in this collection.
 
+        If `to_save` already has an '_id' then an update (upsert) operation
+        is performed and any existing document with that _id is overwritten.
+        Otherwise an insert operation is performed. Returns the _id of the
+        saved document.
+
         Raises TypeError if to_save is not an instance of dict. If `safe`
         is True then the save will be checked for errors, raising
         OperationFailure if one occurred. Checking for safety requires an extra
@@ -164,7 +169,7 @@ class Collection(object):
 
         :Parameters:
           - `doc_or_docs`: a SON object or list of SON objects to be inserted
-          - `manipulate` (optional): monipulate the documents before inserting?
+          - `manipulate` (optional): manipulate the documents before inserting?
           - `safe` (optional): check that the insert succeeded?
           - `check_keys` (optional): check if keys start with '$' or
             contain '.', raising `pymongo.errors.InvalidName` in either case
@@ -192,7 +197,7 @@ class Collection(object):
 
     def update(self, spec, document,
                upsert=False, manipulate=False, safe=False):
-        """Update an object(s) in this collection.
+        """Update a document(s) in this collection.
 
         Raises TypeError if either spec or document isn't an instance of
         dict or upsert isn't an instance of bool. If `safe` is True then
@@ -205,9 +210,9 @@ class Collection(object):
             a document to be updated
           - `document`: a SON object specifying the fields to be changed in the
             selected document(s), or (in the case of an upsert) the document to
-            be inserted.
+            be inserted
           - `upsert` (optional): perform an upsert operation
-          - `manipulate` (optional): monipulate the document before updating?
+          - `manipulate` (optional): manipulate the document before updating?
           - `safe` (optional): check that the update succeeded?
         """
         if not isinstance(spec, types.DictType):
@@ -252,7 +257,8 @@ class Collection(object):
 
         self._send_message(2006, _ZERO + bson.BSON.from_dict(spec))
 
-    def find_one(self, spec_or_object_id=None, _sock=None):
+    def find_one(self, spec_or_object_id=None, fields=None, slave_okay=None,
+                 _sock=None):
         """Get a single object from the database.
 
         Raises TypeError if the argument is of an improper type. Returns a
@@ -260,9 +266,15 @@ class Collection(object):
 
         :Parameters:
           - `spec_or_object_id` (optional): a SON object specifying elements
-            which must be present for a document to be included in the result
-            set OR an instance of ObjectId to be used as the value for an _id
-            query
+            which must be present for a document to be returned OR an instance
+            of ObjectId to be used as the value for an _id query
+          - `fields` (optional): a list of field names that should be included
+            in the returned document ("_id" will always be included)
+          - `slave_okay` (optional): if True, this query should be allowed to
+            execute on a slave (by default, certain queries are not allowed to
+            execute on mongod instances running in slave mode). If slave_okay
+            is set to None the Connection level default will be used - see the
+            slave_okay parameter to `pymongo.Connection.__init__`.
         """
         spec = spec_or_object_id
         if spec is None:
@@ -270,7 +282,8 @@ class Collection(object):
         if isinstance(spec, ObjectId):
             spec = SON({"_id": spec})
 
-        for result in self.find(spec, limit=-1, _sock=_sock):
+        for result in self.find(spec, limit=-1, fields=fields,
+                                slave_okay=slave_okay, _sock=_sock):
             return result
         return None
 
@@ -291,7 +304,8 @@ class Collection(object):
             as_dict[field] = 1
         return as_dict
 
-    def find(self, spec=None, fields=None, skip=0, limit=0, _sock=None):
+    def find(self, spec=None, fields=None, skip=0, limit=0,
+             slave_okay=None, snapshot=False, _sock=None):
         """Query the database.
 
         The `spec` argument is a prototype document that all results must
@@ -303,7 +317,7 @@ class Collection(object):
         Matches can have other keys *in addition* to "hello". The `fields`
         argument is used to specify a subset of fields that should be included
         in the result documents. By limiting results to a certain subset of
-        fields we cut down on network traffic and decoding time.
+        fields you can cut down on network traffic and decoding time.
 
         Raises TypeError if any of the arguments are of improper type. Returns
         an instance of Cursor corresponding to this query.
@@ -317,9 +331,22 @@ class Collection(object):
             of the result set) when returning the results
           - `limit` (optional): the maximum number of results to return in the
             first reply message, or 0 for the default return size
+          - `slave_okay` (optional): if True, this query should be allowed to
+            execute on a slave (by default, certain queries are not allowed to
+            execute on mongod instances running in slave mode). If slave_okay
+            is set to None the Connection level default will be used - see the
+            slave_okay parameter to `pymongo.Connection.__init__`.
+          - `snapshot` (optional): if True, snapshot mode will be used for this
+            query. Snapshot mode assures no duplicates are returned, or objects
+            missed, which were present at both the start and end of the query's
+            execution. For details, see the wiki_
+
+        .. _wiki: http://www.mongodb.org/display/DOCS/How+to+do+Snapshotting+in+the+Mongo+Database
         """
         if spec is None:
             spec = SON()
+        if slave_okay is None:
+            slave_okay = self.__database.connection().slave_okay
         if not isinstance(spec, types.DictType):
             raise TypeError("spec must be an instance of dict")
         if not isinstance(fields, (types.ListType, types.NoneType)):
@@ -328,13 +355,22 @@ class Collection(object):
             raise TypeError("skip must be an instance of int")
         if not isinstance(limit, types.IntType):
             raise TypeError("limit must be an instance of int")
+        if not isinstance(slave_okay, types.BooleanType):
+            raise TypeError("slave_okay must be an instance of bool")
+        if not isinstance(snapshot, types.BooleanType):
+            raise TypeError("snapshot must be an instance of bool")
 
         if fields is not None:
+            if not fields:
+                fields = ["_id"]
             fields = self._fields_list_to_dict(fields)
 
-        return Cursor(self, spec, fields, skip, limit, _sock=_sock)
+        return Cursor(self, spec, fields, skip, limit, slave_okay, snapshot,
+                      _sock=_sock)
 
     def count(self):
+        """Get the number of documents in this collection.
+        """
         return self.find().count()
 
     def _gen_index_name(self, keys):
@@ -486,7 +522,7 @@ class Collection(object):
 
         return options
 
-    def group(self, keys, condition, initial, reduce):
+    def group(self, keys, condition, initial, reduce, command=False):
         """Perform a query similar to an SQL group by operation.
 
         Returns an array of grouped items.
@@ -497,7 +533,18 @@ class Collection(object):
             query specification)
           - `initial`: initial value of the aggregation counter object
           - `reduce`: aggregation function as a JavaScript string
+          - `command` (optional): if True, run the group as a command instead
+            of in an eval - it is likely that this option will eventually be
+            deprecated and all groups will be run as commands
         """
+        if command:
+            return self.__database._command({"group":
+                                                 {"ns": self.__collection_name,
+                                                  "$reduce": Code(reduce),
+                                                  "key": self._fields_list_to_dict(keys),
+                                                  "cond": condition,
+                                                  "initial": initial}})["retval"]
+
         group_function = """function () {
     var c = db[ns].find(condition);
     var map = new Map();
@@ -506,8 +553,9 @@ class Collection(object):
         var obj = c.next();
 
         var key = {};
-        for (var i in keys) {
-            key[keys[i]] = obj[keys[i]];
+        for (var i = 0; i < keys.length; i++) {
+            var k = keys[i];
+            key[k] = obj[k];
         }
 
         var aggObj = map.get(key);
@@ -526,6 +574,33 @@ class Collection(object):
                                           "condition": condition,
                                           "initial": initial}))["result"]
 
+    def rename(self, new_name):
+        """Rename this collection.
+
+        If operating in auth mode, client must be authorized as an admin to
+        perform this operation. Raises TypeError if new_name is not an instance
+        of (str, unicode). Raises InvalidName if new_name is not a valid
+        collection name.
+
+        :Parameters:
+          - `new_name`: new name for this collection
+        """
+        if not isinstance(new_name, types.StringTypes):
+            raise TypeError("new_name must be an instance of (str, unicode)")
+
+        if not new_name or ".." in new_name:
+            raise InvalidName("collection names cannot be empty")
+        if "$" in new_name:
+            raise InvalidName("collection names must not contain '$'")
+        if new_name[0] == "." or new_name[-1] == ".":
+            raise InvalidName("collecion names must not start or end with '.'")
+
+        rename_command = SON([("renameCollection", self.full_name()),
+                              ("to", "%s.%s" % (self.__database.name(),
+                                                new_name))])
+
+        self.__database.connection().admin._command(rename_command)
+
     def __iter__(self):
         return self
 
