@@ -35,7 +35,8 @@ class Cursor(object):
     """A cursor / iterator over Mongo query results.
     """
 
-    def __init__(self, collection, spec, fields, skip, limit, _sock=None):
+    def __init__(self, collection, spec, fields, skip, limit, slave_okay,
+                 snapshot=False, _sock=None):
         """Create a new cursor.
 
         Should not be called directly by application developers.
@@ -45,7 +46,8 @@ class Cursor(object):
         self.__fields = fields
         self.__skip = skip
         self.__limit = limit
-        self.__slave_okay = collection.database().connection().slave_okay
+        self.__slave_okay = slave_okay
+        self.__snapshot = snapshot
         self.__ordering = None
         self.__explain = False
         self.__hint = None
@@ -87,8 +89,8 @@ class Cursor(object):
         completely evaluated.
         """
         copy = Cursor(self.__collection, self.__spec, self.__fields,
-                      self.__skip, self.__limit)
-        copy.__slave_okay = self.__slave_okay
+                      self.__skip, self.__limit, self.__slave_okay,
+                      self.__snapshot)
         copy.__ordering = self.__ordering
         copy.__explain = self.__explain
         copy.__hint = self.__hint
@@ -122,6 +124,8 @@ class Cursor(object):
             spec["$explain"] = True
         if self.__hint:
             spec["$hint"] = self.__hint
+        if self.__snapshot:
+            spec["$snapshot"] = True
         return spec
 
     def __query_options(self):
@@ -138,8 +142,12 @@ class Cursor(object):
         if self.__retrieved or self.__id is not None:
             raise InvalidOperation("cannot set options after executing query")
 
+    # TODO complete deprecation by removing this method
     def slave_okay(self, slave_okay=True):
-        """Specify whether this query should be allowed to execute on a slave.
+        """(DEPRECATED) Specify whether this query should be allowed to execute on a slave.
+
+        This method is deprecated and will be removed. Use the slave_okay
+        parameter to `pymongo.collection.Collection.find` instead.
 
         By default, certain queries are not allowed to execute on mongod
         instances running in slave mode. If `slave_okay` is True then this
@@ -157,6 +165,9 @@ class Cursor(object):
           - `slave_okay` (optional): should this query be allowed to execute on
             slave instances
         """
+        warnings.warn("the slave_okay method is deprecated and will"
+                      " be removed - use the slave_okay paramater to find()"
+                      " instead", DeprecationWarning)
         self.__check_okay_to_chain()
 
         self.__slave_okay = slave_okay
@@ -221,12 +232,9 @@ class Cursor(object):
         """Get the size of the results set for this query.
 
         Returns the number of objects in the results set for this query. Does
-        not take limit and skip into account. Raises InvalidOperation if this
-        cursor has already been used. Raises OperationFailure on a database
-        error.
+        not take limit and skip into account. Raises OperationFailure on a
+        database error.
         """
-        self.__check_okay_to_chain()
-
         command = SON([("count", self.__collection.name()),
                        ("query", self.__spec)])
         response = self.__collection.database()._command(command,
@@ -395,9 +403,7 @@ class Cursor(object):
 
     def next(self):
         db = self.__collection.database()
-        if len(self.__data):
-            next = db._fix_outgoing(self.__data.pop(0), self.__collection)
-        elif self._refresh():
+        if len(self.__data) or self._refresh():
             next = db._fix_outgoing(self.__data.pop(0), self.__collection)
         else:
             raise StopIteration
