@@ -15,7 +15,8 @@
 """Manipulators that can edit SON objects as they enter and exit a database.
 
 New manipulators should be defined as subclasses of SONManipulator and can be
-installed on a database by calling `pymongo.database.Database.add_son_manipulator`."""
+installed on a database by calling
+`pymongo.database.Database.add_son_manipulator`."""
 
 import types
 
@@ -23,17 +24,19 @@ from objectid import ObjectId
 from dbref import DBRef
 from son import SON
 
+
 class SONManipulator(object):
     """A base son manipulator.
 
     This manipulator just saves and restores objects without changing them.
     """
+
     def will_copy(self):
         """Will this SON manipulator make a copy of the incoming document?
 
-        Derived classes that do need to make a copy should override this method,
-        returning True instead of False. All non-copying manipulators will be
-        applied first (so that the user's document will be updated
+        Derived classes that do need to make a copy should override this
+        method, returning True instead of False. All non-copying manipulators
+        will be applied first (so that the user's document will be updated
         appropriately), followed by copying manipulators.
         """
         return False
@@ -60,9 +63,11 @@ class SONManipulator(object):
             return SON(son)
         return son
 
+
 class ObjectIdInjector(SONManipulator):
     """A son manipulator that adds the _id field if it is missing.
     """
+
     def transform_incoming(self, son, collection):
         """Add an _id field if it is missing.
         """
@@ -70,9 +75,11 @@ class ObjectIdInjector(SONManipulator):
             son["_id"] = ObjectId()
         return son
 
+
 class ObjectIdShuffler(SONManipulator):
     """A son manipulator that moves _id to the first position.
     """
+
     def will_copy(self):
         """We need to copy to be sure that we are dealing with SON, not a dict.
         """
@@ -87,15 +94,18 @@ class ObjectIdShuffler(SONManipulator):
         transformed.update(son)
         return transformed
 
+
 class NamespaceInjector(SONManipulator):
     """A son manipulator that adds the _ns field.
     """
+
     def transform_incoming(self, son, collection):
         """Add the _ns field to the incoming object
         """
         son["_ns"] = collection.name()
         return son
 
+
 class AutoReference(SONManipulator):
     """Transparently reference and de-reference already saved embedded objects.
 
@@ -103,6 +113,7 @@ class AutoReference(SONManipulator):
     also being used, otherwise it doesn't make too much sense - documents can
     only be auto-referenced if they have an *_ns* field.
     """
+
     def __init__(self, db):
         self.__database = db
 
@@ -114,6 +125,7 @@ class AutoReference(SONManipulator):
     def transform_incoming(self, son, collection):
         """Replace embedded documents with DBRefs.
         """
+
         def transform_value(value):
             if isinstance(value, types.DictType):
                 if "_id" in value and "_ns" in value:
@@ -134,6 +146,7 @@ class AutoReference(SONManipulator):
     def transform_outgoing(self, son, collection):
         """Replace DBRefs with embedded documents.
         """
+
         def transform_value(value):
             if isinstance(value, DBRef):
                 return self.__database.dereference(value)
